============================
So You Want to Contribute...
============================

For general information on contributing to OpenStack, please check out the
`contributor guide <https://docs.openstack.org/contributors/>`_ to get started.
It covers all the basics that are common to all OpenStack projects: the
accounts you need, the basics of interacting with our Gerrit review system, how
we communicate as a community, etc.

Below will cover the more project specific information you need to get started
with Sahara.

Communication
~~~~~~~~~~~~~
* If you have something to discuss use
  `OpenStack development mail-list <http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss>`_.
  Prefix the mail subject with ``[sahara]``

* Join ``#openstack-sahara`` IRC channel on `OFTC <http://oftc.net>`_

* Attend Sahara team meetings

  * Weekly on Thursdays at 1400 UTC

  * IRC channel: ``#openstack-meeting-3``

Contacting the Core Team
~~~~~~~~~~~~~~~~~~~~~~~~
* The core team has coverage in the timezones of Europe and the Americas.

* Just pop over to IRC; we keep a close eye on it!

* You can also find the email addresses of the core team `here
  https://review.opendev.org/#/admin/groups/133,members>`.

New Feature Planning
~~~~~~~~~~~~~~~~~~~~
Sahara uses specs to track feature requests. They provide a high-level summary
of proposed changes and track associated commits. Sahara also uses specs for
in-depth descriptions and discussions of blueprints. Specs follow a defined
format and are submitted as change requests to the openstack/sahara-specs
repository.

Task Tracking
~~~~~~~~~~~~~
We track our tasks in Storyboard.

The Sahara project group homepage on Storyboard is
https://storyboard.openstack.org/#!/project_group/sahara.

If you're looking for some smaller, easier work item to pick up and get started
on, search for the 'low-hanging-fruit' or 'new-contributor' tag.

Reporting a Bug
~~~~~~~~~~~~~~~
You found an issue and want to make sure we are aware of it? You can do so on
https://storyboard.openstack.org/#!/project_group/sahara.

Getting Your Patch Merged
~~~~~~~~~~~~~~~~~~~~~~~~~
Typically two +2s are required before merging.

Project Team Lead Duties
~~~~~~~~~~~~~~~~~~~~~~~~
If you are the PTL of Sahara then you should follow the `PTL guide
<https://docs.openstack.org/project-team-guide/ptl.html>`_. You should also
keep track of new versions of the various Hadoop distros/components coming out
(this can also be delegated to another contributor, but the PTL needs to track
it either way).
